---
description: Get familiar with the distilabel's pipelines.
---

# Overview of Distilabel

AI Feedback (AIF) framework to build datasets with and for LLMs:

## Pipeline

Define your pipeline like you would a Directed Acyclic Graph (DAG)...

## Steps

...

## Command Line Interface

Distilabel comes with a CLI to easily reproduce datasets from a `pipeline.yaml`.
...

